# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/inventory/item/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/inventory/item/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Inventory\\Item\\": "packages/inventory/item/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Inventory\Item\Providers\ItemServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Item'  => Inventory\Item\Facades\Item::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Inventory\\ItemTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Inventory\Item\Providers\ItemServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Inventory\Item\Providers\ItemServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Inventory\Item\Providers\ItemServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/item/{modulename}

**User**

    http://path-to-route-folder/user/item/{modulename}

**Public**

    http://path-to-route-folder/items


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/item/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/item/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/item/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/item/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/item/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/item/{modulename}/{slug}
    METHOD: GET