<?php

namespace Inventory\Item\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Inventory\Item\Models\Item;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Inventory\Item\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/item/unit/*')) {
            Route::bind('unit', function ($unit) {
                $unitrepo = $this->app->make('Inventory\Item\Interfaces\UnitRepositoryInterface');
                return $unitrepo->findorNew($unit);
            });
        }
        if (Request::is('*/item/item/*')) {
            Route::bind('item', function ($item) {
                $itemrepo = $this->app->make('Inventory\Item\Interfaces\ItemRepositoryInterface');
                return $itemrepo->findorNew($item);
            });
        }
        if (Request::is('*/item/category/*')) {
            Route::bind('category', function ($category) {
                $categoryrepo = $this->app->make('Inventory\Item\Interfaces\CategoryRepositoryInterface');
                return $categoryrepo->findorNew($category);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
